# BPpy: Behavioral Programming In Python
A Python implementation for the Behavioral Programming paradigm

## Installation
You can install ``bppy`` with pip:

```shell
pip install bppy
```

## Documentation
* [BPpy documentation](https://bppy.readthedocs.io/en/latest/)
* General introduction to Behavioral Programming can be found in [this](https://bpjs.readthedocs.io/en/develop/) BPjs tutorial and others

## Citing BPpy
To cite this repository in publications:
```
@misc{bppy,
  author = {Tom Yaacov},
  title = {BPpy: Behavioral Programming In Python},
  year = {2020},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/bThink-BGU/BPpy}},
}
```
